@@ -44,13 +44,13 @@ edisplay = Bonito.use_electron_display(devtools = true)
         # are modified in which case the numbers should just be updated
         f, a, p = scatter(rand(10))
         colorbuffer(f)
-        @test length(p.attributes.inputs) == 44
-        @test length(p.attributes.outputs) == 96
+        @test length(p.attributes.inputs) == 43
+        @test length(p.attributes.outputs) == 97
     end
 
     @testset "refimages" begin
         ReferenceTests.mark_broken_tests(excludes)
-        recorded_files, recording_dir = @include_reference_tests WGLMakie "refimages.jl"
+        recorded_files, recording_dir = @include_reference_tests WGLMakie "refimages.jl" joinpath(@__DIR__, "html_widgets_refimages.jl")
         missing_images, scores = ReferenceTests.record_comparison(recording_dir, "WGLMakie")
         ReferenceTests.test_comparison(scores; threshold = 0.05)
     end
@@ -242,6 +242,10 @@ edisplay = Bonito.use_electron_display(devtools = true)
         end
     end
 
+    @testset "html-widgets" begin
+        include("html-widgets.jl")
+    end
+
     @testset "memory leaks" begin
         Makie.CURRENT_FIGURE[] = nothing
         app = App(nothing)
